#[non_exhaustive]pub struct CreateContainerAssociationOutput {
pub container_association_name: Option<String>,
pub container_association_arn: Option<String>,
pub description: Option<String>,
pub type: Option<ContainerMonitoringType>,
pub container_monitoring_configurations: Option<Vec<ContainerMonitoringConfiguration>>,
pub status: Option<ContainerAssociationStatus>,
pub tags: Option<Vec<Tag>>,
pub update_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.container_association_name: Option<String>The descriptive name of the container association.
container_association_arn: Option<String>The Amazon Resource Name (ARN) of the container association.
description: Option<String>A description of the container association.
type: Option<ContainerMonitoringType>The type of container orchestration platform. Either ECS or EKS.
container_monitoring_configurations: Option<Vec<ContainerMonitoringConfiguration>>The container monitoring configurations for this container association.
status: Option<ContainerAssociationStatus>The current status of the container association.
The key:value pairs associated with the resource.
update_token: Option<String>A token used for optimistic locking. Network Firewall returns a token to your requests that access the container association. The token marks the state of the container association resource at the time of the request. To make an update to the container association, provide the token in your request. Network Firewall uses the token to ensure that the container association hasn't changed since you last retrieved it. If it has changed, the operation fails with an InvalidTokenException. If this happens, retrieve the container association again to get a current copy of it with a new token. Reapply your changes as needed, then try the operation again using the new token.
Implementations
Sourceimpl CreateContainerAssociationOutput
impl CreateContainerAssociationOutput
Sourcepub fn container_association_name(&self) -> Option<&str>
pub fn container_association_name(&self) -> Option<&str>
The descriptive name of the container association.
Sourcepub fn container_association_arn(&self) -> Option<&str>
pub fn container_association_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the container association.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the container association.
Sourcepub fn type(&self) -> Option<&ContainerMonitoringType>
pub fn type(&self) -> Option<&ContainerMonitoringType>
The type of container orchestration platform. Either ECS or EKS.
Sourcepub fn container_monitoring_configurations(
&self,
) -> &[ContainerMonitoringConfiguration]
pub fn container_monitoring_configurations( &self, ) -> &[ContainerMonitoringConfiguration]
The container monitoring configurations for this container association.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .container_monitoring_configurations.is_none().
Sourcepub fn status(&self) -> Option<&ContainerAssociationStatus>
pub fn status(&self) -> Option<&ContainerAssociationStatus>
The current status of the container association.
The key:value pairs associated with the resource.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourcepub fn update_token(&self) -> Option<&str>
pub fn update_token(&self) -> Option<&str>
A token used for optimistic locking. Network Firewall returns a token to your requests that access the container association. The token marks the state of the container association resource at the time of the request. To make an update to the container association, provide the token in your request. Network Firewall uses the token to ensure that the container association hasn't changed since you last retrieved it. If it has changed, the operation fails with an InvalidTokenException. If this happens, retrieve the container association again to get a current copy of it with a new token. Reapply your changes as needed, then try the operation again using the new token.
Sourceimpl CreateContainerAssociationOutput
impl CreateContainerAssociationOutput
Sourcepub fn builder() -> CreateContainerAssociationOutputBuilder
pub fn builder() -> CreateContainerAssociationOutputBuilder
Creates a new builder-style object to manufacture CreateContainerAssociationOutput.